import { Issue, PullRequest } from './github';
import { Query } from './options';
import * as Wrapped from './github';
export declare type IssuePageFetchResult = {
    issues: GitHubAPI.Issue[];
    fetchMore?: () => Promise<IssuePageFetchResult>;
};
export declare function initialize(_oauthToken: string): void;
export declare function getMyLogin(): Promise<string>;
export declare function addLabels(issue: Wrapped.Issue, labels: string[]): Promise<void>;
export declare function removeLabels(issue: Wrapped.Issue, labels: string[]): Promise<void>;
export declare function setLabels(issue: Wrapped.Issue, labels: string[]): Promise<void>;
export declare function lockIssue(issue: Wrapped.Issue): Promise<void>;
export declare function unlockIssue(issue: Wrapped.Issue): Promise<void>;
export declare function closeIssue(issue: Wrapped.Issue): Promise<void>;
export declare function reopenIssue(issue: Wrapped.Issue): Promise<void>;
export declare function addComment(issue: Wrapped.Issue, body: string): Promise<void>;
export declare function editComment(comment: Wrapped.IssueComment, body: string): Promise<void>;
export declare type IssuePageResult = {
    page: GitHubAPI.Issue[];
    next?(): Promise<IssuePageResult>;
};
export declare function fetchAllIssuesAndPRsRaw(repo: GitHubAPI.RepoReference): Promise<IssuePageResult>;
export declare function fetchChangedIssuesRaw(repo: GitHubAPI.RepoReference): Promise<GitHubAPI.Issue[]>;
export declare function runQuery(q: Query, callback: (item: PullRequest | Issue) => Promise<void>): Promise<void>;
export declare function fetchChangedPRsRaw(repo: GitHubAPI.RepoReference): Promise<GitHubAPI.PullRequestFromList[]>;
export declare function fetchProjectColumns(projectId: number): Promise<GitHubAPI.ProjectColumn[]>;
export declare function fetchProjectColumnCards(columnId: number): Promise<GitHubAPI.ProjectColumnCard[]>;
export declare function createProjectCard(columnId: number, issue: Wrapped.IssueOrPullRequest): Promise<void>;
export declare function moveProjectCard(card: Wrapped.ProjectCard, targetColumn: Wrapped.ProjectColumn): Promise<void>;
export declare function deleteProjectCard(card: Wrapped.ProjectCard): Promise<void>;
export declare function fetchIssueComments(issue: Wrapped.Issue): Promise<GitHubAPI.IssueComment[]>;
export declare function fetchPRCommits(issue: Wrapped.PullRequest): Promise<GitHubAPI.PullRequestCommit[]>;
export declare function fetchPRFiles(issue: Wrapped.PullRequest): Promise<GitHubAPI.PullRequestFile[]>;
export declare function fetchIssueCommentReactions(repo: GitHubAPI.RepoReference, commentId: number): Promise<GitHubAPI.Reaction[]>;
export declare function fetchPR(repo: GitHubAPI.RepoReference, number: number | string): Promise<GitHubAPI.PullRequest>;
export declare function fetchIssue(repo: GitHubAPI.RepoReference, number: number | string): Promise<GitHubAPI.Issue>;
export declare function fetchPRReviews(repo: GitHubAPI.RepoReference, number: number): Promise<GitHubAPI.PullRequestReview[]>;
export declare function fetchRefStatusSummary(repo: GitHubAPI.RepoReference, ref: string): Promise<GitHubAPI.CombinedStatus>;
export interface ExecOptions {
    queryString?: {
        [key: string]: string;
    };
    body?: string;
    preview?: string;
}
export declare function exec(method: string, path: string, opts?: ExecOptions): Promise<string>;
