/**
 * KeyType: a reference or value type that uniquely identifies an InstanceType
 * DataType: the type of the JSON data that comes from GitHub
 * InstanceType: the instance type of the constructed class
 * ExtraType: the type of extra data needed to instantiate the class
 */
export interface Settings<KeyType, DataType, InstanceType, ExtraType> {
    /** Class constructor for creating a new InstanceType */
    constructor: new (data: DataType, extra: ExtraType) => InstanceType;
    /** Fetch a key from the data type */
    keyOf(data: DataType): KeyType;
    /** Fetch the data for this based on the key */
    fetchData(key: KeyType): Promise<DataType>;
    /** Construct a string representation of a key */
    keyToString(key: KeyType): string;
}
export interface IUpdateable<DataType> {
    update(data: DataType): void;
}
export declare class Pool<KeyType, DataType, InstanceType extends IUpdateable<DataType>, ExtraType> {
    private settings;
    private pool;
    constructor(settings: Settings<KeyType, DataType, InstanceType, ExtraType>);
    get(key: KeyType): Promise<InstanceType>;
    instantiate(data: DataType, extra?: ExtraType): InstanceType;
}
