"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const pool_1 = require("./pool");
const client = require("./client");
const Wrapped = require("./github");
const weak_string_map_1 = require("./weak-string-map");
let cache = undefined;
function useCache(c) {
    cache = c;
}
exports.useCache = useCache;
function keyFromIssue(issue) {
    const repo = Wrapped.parseRepoReference(issue.repository_url);
    return [repo.owner, repo.name, issue.number];
}
exports.Issues = new pool_1.Pool({
    constructor: Wrapped.Issue,
    keyToString: (key) => key[0] + '/' + key[1] + '#' + key[2],
    keyOf: keyFromIssue,
    fetchData: (key) => __awaiter(this, void 0, void 0, function* () {
        const timestamp = new Date();
        const data = JSON.parse(yield client.exec('GET', path('repos', key[0], key[1], 'issues', key[2])));
        cache && (yield cache.save(data, Wrapped.Issue.getCacheKey({ owner: key[0], name: key[1] }, data.number, !!data.pull_request), timestamp));
        return data;
    })
});
exports.Users = new pool_1.Pool({
    constructor: Wrapped.User,
    keyToString: (k) => k,
    keyOf: data => data.login,
    fetchData: (login) => __awaiter(this, void 0, void 0, function* () {
        const data = yield client.exec('GET', path('users', login));
        return JSON.parse(data);
    }),
});
exports.IssueComments = new pool_1.Pool({
    constructor: Wrapped.IssueComment,
    fetchData: () => {
        throw new Error('Cannot fetch issue comment directly');
    },
    keyToString: id => id.toString(),
    keyOf: raw => raw.id
});
var Labels;
(function (Labels) {
    const pool = new weak_string_map_1.default();
    function get(repo, data) {
        const key = [repo.owner, repo.name, ':label:', data.name].join('/');
        let value = pool.get(key);
        if (value !== undefined) {
            return value;
        }
        value = new Wrapped.Label(repo, data);
        pool.set(key, value);
        return value;
    }
    Labels.get = get;
})(Labels = exports.Labels || (exports.Labels = {}));
function path(...parts) {
    return '/' + parts.map(encodeURIComponent).join('/');
}
