"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function parseQuery(json) {
    if ('kind' in json) {
        var kind = json['kind'];
        switch (kind) {
            case 'prs':
                return parsePrsQuery(json);
            case 'issues':
                throw new Error("Issue queries NYI");
            default:
                throw new Error("Query kind '" + kind + "' must be \"prs\" or \"issues\"");
        }
    }
    else {
        throw new Error('Must specify "kind" property');
    }
}
exports.parseQuery = parseQuery;
function parsePrsQuery(json) {
    var repo = getProperty(json, 'repo', null, function (r) { return /\w+\/\w+/.test(r); });
    var state = getProperty(json, 'state', 'open', function (x) { return ['open', 'closed', 'all'].indexOf(x) >= 0; });
    var count = getProperty(json, 'count', 'all', function (n) { return n === 'all' || typeof n === 'number'; });
    var sort = getProperty(json, 'sort', 'created', function (x) { return ['created', 'updated', 'popularity', 'long-running'].indexOf(x) >= 0; });
    var direction = getProperty(json, 'direction', 'desc', function (x) { return ['asc', 'desc'].indexOf(x) >= 0; });
    return ({
        repo: repo,
        kind: 'prs',
        state: state,
        count: count,
        sort: sort,
        direction: direction
    });
}
function getProperty(json, key, defaultValue, validate) {
    if (key in json) {
        var value = json[key];
        if (!validate(value)) {
            throw new Error("Invalid value for '" + key + "'");
        }
        return value;
    }
    else {
        if (defaultValue === null) {
            throw new Error("Must specify value for '" + key + "'");
        }
        else {
            return defaultValue;
        }
    }
}
